@@ -108,11 +108,11 @@ class TwelveData():
             timezone="Africa/Johannesburg",
         )
 
-        dataHistory = ts.with_percent_b().with_apo().with_supertrend().with_trange().as_pandas()
+        dataHistory = ts.with_percent_b().with_stoch(slow_k_period=3).with_apo().with_supertrend().with_trange().with_ultosc().as_pandas()
         return dataHistory
 
             
-    def getRealTime(self, lookback=150):
+    def getRealTime(self, lookback=120):
 
         ts = self.td.time_series(
             symbol=self.asset,
@@ -122,11 +122,10 @@ class TwelveData():
             timezone="Africa/Johannesburg",
         )
 
-        dataReal = ts.with_percent_b().with_apo().with_supertrend().with_trange().as_pandas()
+        dataReal = ts.with_percent_b().with_stoch(slow_k_period=3).with_apo().with_supertrend().with_trange().with_ultosc().as_pandas()
 
         data = dataReal.sort_index(ascending=True)
         data = data[["open","high","low","close","percent_b","slow_k","slow_d","apo","supertrend","trange","ultosc"]]
-        obs  = data.tail(15).values
-        obs  = obs.reshape(165,)
+        obs  = obs.reshape(1320,)
 
         return obs
\ No newline at end of file
